@@ -1,21 +1,31 @@
 #' Plot a 2D slice from an MRSI fit result object.
 #' @param fit_res \code{fit_result} object.
-#' @param map array of values to be plotted, defaults to a "tNAA" map.
+#' @param map fit result values to display as a colour map. Can be specified as
+#' a character string or array of numeric values. Defaults to "tNAA".
+#' @param map_denom fit result values to divide the map argument by. Can be
+#' specified as a character string (eg "tCr") or array of numeric values.
 #' @param slice slice to plot in the z direction.
 #' @param zlim range of values to plot.
 #' @param interp interpolation factor.
 #' @param xlim spectral plot limits for the x axis.
 #' @export
-plot_slice_fit_inter <- function(fit_res, map = NULL, slice = 1, zlim = NULL, 
-                                 interp = 1, xlim = NULL) {
+plot_slice_fit_inter <- function(fit_res, map = NULL, map_denom = NULL, 
+                                 slice = 1, zlim = NULL, interp = 1,
+                                 xlim = NULL) {
+  
+  if (class(map) == "character") map <- get_fit_map(fit_res, map)
+  
+  if (class(map_denom) == "character") map_denom <- get_fit_map(fit_res,
+                                                                map_denom)
   
   if (is.null(map)) map <- get_fit_map(fit_res, "tNAA") 
   
+  if (!is.null(map_denom)) map <- map / map_denom
+  
   plot_slice_map_inter(mrs_data = fit_res, map = map, slice = slice, 
                        interp = interp, zlim = zlim, xlim = xlim)
 }
 
-
 #' Plot an interactive slice map from a data array where voxels can be selected
 #' to display a corresponding spectrum.
 #' @param mrs_data spectral data.
@@ -44,14 +54,17 @@ plot_slice_map_inter <- function(mrs_data, map = NULL, xlim = NULL, slice = 1,
   
   if (class(mrs_data) == "mrs_data") {
     x_scale <- ppm(mrs_data)
+    input_mrs_data <- TRUE
+  } else if (class(mrs_data) == "fit_result") {
+    x_scale  <- ppm(mrs_data)
+    fit_res  <- mrs_data
+    mrs_data <- fit_res$data
+    input_mrs_data <- FALSE
   } else {
-    non_na_res <- which(!is.na(mrs_data$fits))[[1]]
-    x_scale <- mrs_data$fits[[non_na_res]]$PPMScale
+    stop("input is not an mrs_data or fit_result object")
   }
   
-  if (is.null(xlim)) {
-    xlim <- c(x_scale[1], x_scale[length(x_scale)])
-  }
+  if (is.null(xlim)) xlim <- c(x_scale[1], x_scale[length(x_scale)])
   
   ui <- miniUI::miniPage(
     miniUI::gadgetTitleBar("Select point on the map to show spectrum."),
@@ -83,12 +96,12 @@ plot_slice_map_inter <- function(mrs_data, map = NULL, xlim = NULL, slice = 1,
                        lw = 3)
     })
     output$spec <- shiny::renderPlot({
-      if (class(mrs_data) == "mrs_data") {
+      if (input_mrs_data) {
         graphics::plot(mrs_data, x_pos = x, y_pos = Ny(mrs_data) + 1 - y,
                        z_pos = slice, xlim = xlim, mode = mode,
                        y_scale = y_scale, ylim = ylim, coil = coil)
       } else {
-        graphics::plot(mrs_data, x_pos = x, y_pos = Ny(mrs_data) + 1 - y,
+        graphics::plot(fit_res, x_pos = x, y_pos = Ny(mrs_data) + 1 - y,
                        z_pos = slice, xlim = xlim, coil = coil)
       }
       
@@ -114,12 +127,12 @@ plot_slice_map_inter <- function(mrs_data, map = NULL, xlim = NULL, slice = 1,
       if (y < 1) y <- 1
       
       output$spec <- shiny::renderPlot({
-        if (class(mrs_data) == "mrs_data") {
+        if (input_mrs_data) {
           graphics::plot(mrs_data, x_pos = x, y_pos = Ny(mrs_data) + 1 - y,
                          z_pos = slice, xlim = xlim, mode = mode,
                          y_scale = y_scale, ylim = ylim, coil = coil)
         } else {
-          graphics::plot(mrs_data, x_pos = x, y_pos = Ny(mrs_data) + 1 - y,
+          graphics::plot(fit_res, x_pos = x, y_pos = Ny(mrs_data) + 1 - y,
                          z_pos = slice, xlim = xlim, coil = coil)
         }
       })
