@@ -198,6 +198,10 @@ measure_lorentz_amp <- function(y, t, start_pnt = 10, end_pnt = 50) {
 }
 
 measure_td_amp <- function(y, start_pnt = 10, end_pnt = 50) {
+  
+  # check for masked data
+  if (is.na(y[1])) return(NA)
+  
   # crop to time region and take Mod
   y <- Mod(y[start_pnt:end_pnt])
   stats::spline(start_pnt:end_pnt, y, xout=1, method = "natural")$y
